==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ToolActionSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionSeparatorDescription } from "./ToolActionSeparatorDescription";
/**
 * @hidden
 */
export let ToolActionSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionSeparatorDescriptionMetadata.a == null) {
                ToolActionSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionSeparatorDescriptionMetadata.c(ToolActionSeparatorDescriptionMetadata.a);
            }
            if (a.j(ToolActionSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionSeparatorDescriptionMetadata.b(a);
            a.aa("ToolActionSeparator", () => new ToolActionSeparatorDescription());
            a.z("ToolActionSeparator", ToolActionSeparatorDescriptionMetadata.a);
        }
    }
    ToolActionSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionSeparatorDescriptionMetadata, 'ToolActionSeparatorDescriptionMetadata');
    ToolActionSeparatorDescriptionMetadata.a = null;
    return ToolActionSeparatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionSeparatorDescription } from "./ToolActionSeparatorDescription";
/**
 * @hidden
 */
export let ToolActionSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionSeparatorDescriptionMetadata.a == null) {
                ToolActionSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionSeparatorDescriptionMetadata.c(ToolActionSeparatorDescriptionMetadata.a);
            }
            if (a.k(ToolActionSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionSeparatorDescriptionMetadata.b(a);
            a.ac("ToolActionSeparator", () => new ToolActionSeparatorDescription());
            a.ab("ToolActionSeparator", ToolActionSeparatorDescriptionMetadata.a);
        }
    }
    ToolActionSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionSeparatorDescriptionMetadata, 'ToolActionSeparatorDescriptionMetadata');
    ToolActionSeparatorDescriptionMetadata.a = null;
    return ToolActionSeparatorDescriptionMetadata;
})();
